# type constants (file, links, empty directories, and directories with items)
FILE = "file"
DIR = "dir"
LINK = "link"
DIRF = "dirf"

# action constants (true for rollback, false for remove)
RM = False
RB = True